--------------------------------------------------------------------
-- Interface Options Panel
--------------------------------------------------------------------


---------------------------
-- create options
---------------------------
function Glance.Functions.createOptionsPanel()

	-- panel list
	---------------------------
	Glance.Panels[1] = {"Glance",GetAddOnMetadata("Glance","Notes")}
	Glance.Panels[2] = {"General Settings","General configuration settings for Glance."}
	Glance.Panels[3] = {"Modules","Enable or disable the following modules in Glance. Individual options for modules can be accessed via Right-Click. Previously enabled modules will remain in memory until the UI is reloaded."}
	Glance.Panels[4] = {"Profiles","This is a very simple profile tool.  Click Save Profile to save this character's options to the profile.  Some modules do not allow settings to be saved.  The mount list, for instance, would not be the same for every character.  When you login to another character, come back to the Profiles option panel and click Load Profile to load the previously saved options.  Click Reload UI to register the changes."}
	
	-- create the panels
	---------------------------
	Glance.Functions.createPanels()
	
	-- about text
	---------------------------
	Glance.Text[1] = {1,15,-60,"Version","GameFontNormal",""}
	Glance.Text[2] = {1,15,-75,GetAddOnMetadata("Glance","Version"),"GameFontHighlight",""}
	Glance.Text[3] = {1,15,-110,"Updated","GameFontNormal",""}
	Glance.Text[4] = {1,15,-125,GetAddOnMetadata("Glance","X-Updated"),"GameFontHighlight",""}
	Glance.Text[5] = {1,15,-160,"Author","GameFontNormal",""}
	Glance.Text[6] = {1,15,-175,GetAddOnMetadata("Glance","Author"),"GameFontHighlight",""}
	Glance.Text[7] = {1,15,-210,"Category","GameFontNormal",""}
	Glance.Text[8] = {1,15,-225,GetAddOnMetadata("Glance","X-Category"),"GameFontHighlight",""}
	Glance.Text[9] = {1,15,-260,"New In This Version","GameFontNormal",""}
	Glance.Text[10] = {1,15,-275,GetAddOnMetadata("Glance","X-New"),"GameFontHighlight",""}
	
	-- general options
	---------------------------
	Glance.Text[22] = {2,0,-60,"If you don't like Glance on top..","GameFontNormal",""}
	Glance.Text[23] = {2,0,-75,"You must reload the UI for this option to take effect.","GameFontHighlight",""}
	Glance.CheckBoxes[8] = {2,15,-100,"showLow","Show Glance at the bottom of the UI",nil,nil}
	
	Glance.Text[11] = {2,0,-140,"Move the following to make room for Glance","GameFontNormal",""}
	Glance.Text[12] = {2,0,-155,"Glance will not release any unchecked frames to other addons until the UI is reloaded.","GameFontHighlight",""}
	Glance.CheckBoxes[1] = {2,15,-180,"movePlayer","Player Frame",nil,function() Glance.Functions.moveUI() end, Glance_Local.Options.showLow}
	Glance.CheckBoxes[2] = {2,15,-200,"moveTarget","Target Frame",nil,function() Glance.Functions.moveUI() end, Glance_Local.Options.showLow}
	Glance.CheckBoxes[3] = {2,15,-220,"moveBuffs","Buffs",nil,function() Glance.Functions.moveUI() end, Glance_Local.Options.showLow}
	Glance.CheckBoxes[4] = {2,15,-240,"moveMinimap","Minimap",nil,function() Glance.Functions.moveUI() end, Glance_Local.Options.showLow}
	
	Glance.Text[13] = {2,0,-280,"Other Options","GameFontNormal",""}
	Glance.CheckBoxes[5] = {2,15,-300,"sendStats","Send stats to party members using Glance",nil}
	Glance.CheckBoxes[6] = {2,15,-320,"timePlayed","Show time played on login",nil}
	Glance.CheckBoxes[7] = {2,15,-340,"gameFont","Use the standard game font (Requires Restart)",nil}
	
	Glance.Text[14] = {2,250,-375,"Select the scale of the Glance bar","GameFontNormal",""}
	Glance.Functions.createSlider("FrameScale",2,Glance_Local.Options.frameScale,0.5,1.5,0.1,291,-420,Glance.Functions.updateFrameScale)
	
	Glance.Text[15] = {2,0,-375,"Select the colors of the Glance bar","GameFontNormal",""}
	Glance.Functions.createSwatch("BarColor","Glance_Panel2",1,18,18,35,-410)
	Glance.Text[16] = {2,45,-396,"Bar Color","GameFontHighlight",""}
	Glance.Functions.createSwatch("BarColorCombat","Glance_Panel2",2,18,18,35,-434)
	Glance.Text[17] = {2,45,-421,"Bar Color (Combat)","GameFontHighlight",""}
	Glance.Functions.createSwatch("BarColorResting","Glance_Panel2",4,18,18,35,-458)
	Glance.Text[18] = {2,45,-446,"Bar Color (Resting)","GameFontHighlight",""}
	Glance.Functions.createSwatch("BarBorder","Glance_Panel2",3,18,18,35,-482)
	Glance.Text[19] = {2,45,-471,"Bar Border Color","GameFontHighlight",""}

	
	-- create the buttons
	---------------------------
	Glance.Functions.createOptionsButton(2,"GLance_Panel2_ReloadUI","RELOAD UI",345,-582,function() StaticPopup_Show("Glance_RELOADUI") end)
	Glance.Functions.createOptionsButton(3,"GLance_Panel3_ReloadUI","RELOAD UI",345,-582,function() StaticPopup_Show("Glance_RELOADUI") end)
	Glance.Functions.createOptionsButton(4,"GLance_Panel4_ReloadUI","RELOAD UI",345,-582,function() StaticPopup_Show("Glance_RELOADUI") end)
	Glance.Functions.createOptionsButton(4,"GLance_Panel4_Save","Save Profile",30,-100,function() Glance.Functions.saveProfile() end)
	Glance.Functions.createOptionsButton(4,"GLance_Panel4_Load","Load Profile",150,-100,function() Glance.Functions.loadProfile() end)
	Glance.Functions.createOptionsButton(4,"GLance_Panel4_Reload","RELOAD UI",270,-100,function() StaticPopup_Show("Glance_RELOADUI") end)
	Glance.Functions.createOptionsButton(2,"GLance_Panel2_Reset","RESET",35,-512,function() 
		local r,g,b,a = unpack(Glance.Variables.defaultFrameColor[1]);
		_G["GlanceSwatchBarColor"].texture:SetTexture(r, g, b, 1)
		r,g,b,a = unpack(Glance.Variables.defaultFrameColor[2]);
		_G["GlanceSwatchBarColorCombat"].texture:SetTexture(r, g, b, 1)
		r,g,b,a = unpack(Glance.Variables.defaultFrameColor[3]);
		_G["GlanceSwatchBarBorder"].texture:SetTexture(r, g, b, 1)
		r,g,b,a = unpack(Glance.Variables.defaultFrameColor[4]);
		_G["GlanceSwatchBarColorResting"].texture:SetTexture(r, g, b, 1)
		Glance_Global.Options.frameColor = Glance.Variables.defaultFrameColor
		Glance.Functions.setBackground(1)
	end)
	
	-- profile text
	---------------------------
	Glance.Text[20] = {4,0,-130,"Current Profile set to:","GameFontNormal",""}
	Glance.Text[21] = {4,130,-130," ","GameFontHighlight","profile is not set.","Glance_Profile_Text"}
	
	
	Glance.Frames.descFrame = CreateFrame("BUTTON", "Glance", Glance_Panel3)
	local tf = Glance.Frames.descFrame
	tf:SetWidth(275)
	tf:SetHeight(415)
	tf:SetPoint("TOPLEFT", 330, -70)
	tf:SetBackdrop(Glance.Arrays.backDrop)
	
	local t = tf:CreateTexture(nil, "BACKGROUND")
	t:SetTexture(0, 0, 0, .5)
	t:SetAllPoints(tf)
	tf.texture = t 	
	tf:Show()
	
	local fs = tf:CreateFontString()
	fs:SetFont(Glance.Variables.fnt_file, 12)
	fs:SetHeight(400)
	fs:SetWidth(265)
	fs:SetNonSpaceWrap(true)
	fs:SetWordWrap(true)
	fs:SetJustifyH("LEFT")
	fs:SetJustifyV("TOP")
	tf:SetFontString(fs)
	
	-- create checkbox/scroll
	---------------------------
	Glance.Functions.createTexts()
	Glance.Functions.createCheckBoxes()
	Glance.Functions.createScrollBars()
	
	-- load button options
	---------------------------
	for k, v in pairs(Glance.Buttons) do
		if Glance.Buttons[k].options then
			Glance.Functions[k].options()
		end
	end
	
	-- profile stored text
	---------------------------
	if Glance_Profile.realm ~= nil and Glance_Profile.name ~= nil and Glance_Profile.date ~= nil and Glance_Profile.time ~= nil then
		_G["Glance_Profile_Text"]:SetText(Glance_Profile.realm.." \\ "..Glance_Profile.name.." on "..Glance_Profile.date.." at "..Glance_Profile.time)
	end
end


Glance.Functions.createOptionsPanel()
Glance.Functions.setOptionValues()